@@ -25,18 +25,17 @@ import (
 	"github.com/snyk/driftctl/enumeration/resource"
 	resourceaws "github.com/snyk/driftctl/enumeration/resource/aws"
 
-	"github.com/snyk/driftctl/test"
 	"github.com/snyk/driftctl/test/goldenfile"
 	"github.com/stretchr/testify/assert"
 )
 
 func TestScanLambdaFunction(t *testing.T) {
-
 	tests := []struct {
-		test    string
-		dirName string
-		mocks   func(*repository.MockLambdaRepository, *mocks.AlerterInterface)
-		err     error
+		test           string
+		dirName        string
+		mocks          func(*repository.MockLambdaRepository, *mocks.AlerterInterface)
+		assertExpected func(*testing.T, []*resource.Resource)
+		err            error
 	}{
 		{
 			test:    "no lambda functions",
@@ -44,6 +43,9 @@ func TestScanLambdaFunction(t *testing.T) {
 			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllLambdaFunctions").Return([]*lambda.FunctionConfiguration{}, nil)
 			},
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 0)
+			},
 			err: nil,
 		},
 		{
@@ -59,6 +61,15 @@ func TestScanLambdaFunction(t *testing.T) {
 					},
 				}, nil)
 			},
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 2)
+
+				assert.Equal(t, "foo", got[0].ResourceId())
+				assert.Equal(t, resourceaws.AwsLambdaFunctionResourceType, got[0].ResourceType())
+
+				assert.Equal(t, "bar", got[1].ResourceId())
+				assert.Equal(t, resourceaws.AwsLambdaFunctionResourceType, got[1].ResourceType())
+			},
 			err: nil,
 		},
 		{
@@ -71,6 +82,12 @@ func TestScanLambdaFunction(t *testing.T) {
 					},
 				}, nil)
 			},
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 1)
+
+				assert.Equal(t, "foo", got[0].ResourceId())
+				assert.Equal(t, resourceaws.AwsLambdaFunctionResourceType, got[0].ResourceType())
+			},
 			err: nil,
 		},
 		{
@@ -82,12 +99,14 @@ func TestScanLambdaFunction(t *testing.T) {
 
 				alerter.On("SendAlert", resourceaws.AwsLambdaFunctionResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsLambdaFunctionResourceType, resourceaws.AwsLambdaFunctionResourceType), alerts.EnumerationPhase)).Return()
 			},
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 0)
+			},
 			err: nil,
 		},
 	}
 
 	factory := terraform.NewTerraformResourceFactory()
-	deserializer := resource.NewDeserializer(factory)
 
 	for _, c := range tests {
 		t.Run(c.test, func(tt *testing.T) {
@@ -97,7 +116,6 @@ func TestScanLambdaFunction(t *testing.T) {
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
-			scanOptions := ScannerOptions{Deep: true}
 			providerLibrary := terraform.NewProviderLibrary()
 			remoteLibrary := common.NewRemoteLibrary()
 
@@ -126,18 +144,18 @@ func TestScanLambdaFunction(t *testing.T) {
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewLambdaFunctionEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsLambdaFunctionResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsLambdaFunctionResourceType, provider, deserializer))
 
 			testFilter := &enumeration.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
 
-			s := NewScanner(remoteLibrary, alerter, scanOptions, testFilter)
+			s := NewScanner(remoteLibrary, alerter, testFilter)
 			got, err := s.Resources()
 			assert.Equal(tt, c.err, err)
 			if err != nil {
 				return
 			}
-			test.TestAgainstGoldenFileNoCty(got, resourceaws.AwsLambdaFunctionResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+
+			c.assertExpected(tt, got)
 			alerter.AssertExpectations(tt)
 			fakeRepo.AssertExpectations(tt)
 		})
@@ -145,12 +163,12 @@ func TestScanLambdaFunction(t *testing.T) {
 }
 
 func TestScanLambdaEventSourceMapping(t *testing.T) {
-
 	tests := []struct {
-		test    string
-		dirName string
-		mocks   func(*repository.MockLambdaRepository, *mocks.AlerterInterface)
-		err     error
+		test           string
+		dirName        string
+		mocks          func(*repository.MockLambdaRepository, *mocks.AlerterInterface)
+		assertExpected func(*testing.T, []*resource.Resource)
+		err            error
 	}{
 		{
 			test:    "no EventSourceMapping",
@@ -158,6 +176,9 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllLambdaEventSourceMappings").Return([]*lambda.EventSourceMappingConfiguration{}, nil)
 			},
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 0)
+			},
 			err: nil,
 		},
 		{
@@ -173,6 +194,15 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 					},
 				}, nil)
 			},
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 2)
+
+				assert.Equal(t, "13ff66f8-37eb-4ad6-a0a8-594fea72df4f", got[0].ResourceId())
+				assert.Equal(t, resourceaws.AwsLambdaEventSourceMappingResourceType, got[0].ResourceType())
+
+				assert.Equal(t, "4ad7e2b3-79e9-4713-9d9d-5af2c01d9058", got[1].ResourceId())
+				assert.Equal(t, resourceaws.AwsLambdaEventSourceMappingResourceType, got[1].ResourceType())
+			},
 			err: nil,
 		},
 		{
@@ -185,6 +215,12 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 					},
 				}, nil)
 			},
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 1)
+
+				assert.Equal(t, "1aa9c4a0-060b-41c1-a9ae-dc304ebcdb00", got[0].ResourceId())
+				assert.Equal(t, resourceaws.AwsLambdaEventSourceMappingResourceType, got[0].ResourceType())
+			},
 			err: nil,
 		},
 		{
@@ -196,12 +232,14 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 
 				alerter.On("SendAlert", resourceaws.AwsLambdaEventSourceMappingResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsLambdaEventSourceMappingResourceType, resourceaws.AwsLambdaEventSourceMappingResourceType), alerts.EnumerationPhase)).Return()
 			},
+			assertExpected: func(t *testing.T, got []*resource.Resource) {
+				assert.Len(t, got, 0)
+			},
 			err: nil,
 		},
 	}
 
 	factory := terraform.NewTerraformResourceFactory()
-	deserializer := resource.NewDeserializer(factory)
 
 	for _, c := range tests {
 		t.Run(c.test, func(tt *testing.T) {
@@ -211,7 +249,6 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
-			scanOptions := ScannerOptions{Deep: true}
 			providerLibrary := terraform.NewProviderLibrary()
 			remoteLibrary := common.NewRemoteLibrary()
 
@@ -240,18 +277,18 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewLambdaEventSourceMappingEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsLambdaEventSourceMappingResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsLambdaEventSourceMappingResourceType, provider, deserializer))
 
 			testFilter := &enumeration.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
 
-			s := NewScanner(remoteLibrary, alerter, scanOptions, testFilter)
+			s := NewScanner(remoteLibrary, alerter, testFilter)
 			got, err := s.Resources()
 			assert.Equal(tt, c.err, err)
 			if err != nil {
 				return
 			}
-			test.TestAgainstGoldenFile(got, resourceaws.AwsLambdaEventSourceMappingResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+
+			c.assertExpected(tt, got)
 			alerter.AssertExpectations(tt)
 			fakeRepo.AssertExpectations(tt)
 		})
