@@ -17,10 +17,10 @@ import (
 
 	testgoogle "github.com/snyk/driftctl/test/google"
 
+	assetpb "cloud.google.com/go/asset/apiv1/assetpb"
 	terraform2 "github.com/snyk/driftctl/test/terraform"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
-	assetpb "google.golang.org/genproto/googleapis/cloud/asset/v1"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 	"google.golang.org/protobuf/types/known/structpb"
@@ -120,7 +120,6 @@ func TestGoogleBigtableInstance(t *testing.T) {
 
 	for _, c := range cases {
 		t.Run(c.test, func(tt *testing.T) {
-			scanOptions := ScannerOptions{}
 			providerLibrary := terraform.NewProviderLibrary()
 			remoteLibrary := common.NewRemoteLibrary()
 
@@ -147,7 +146,7 @@ func TestGoogleBigtableInstance(t *testing.T) {
 			testFilter := &enumeration.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
 
-			s := NewScanner(remoteLibrary, alerter, scanOptions, testFilter)
+			s := NewScanner(remoteLibrary, alerter, testFilter)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -156,7 +155,7 @@ func TestGoogleBigtableInstance(t *testing.T) {
 			alerter.AssertExpectations(tt)
 			testFilter.AssertExpectations(tt)
 			if c.assertExpected != nil {
-				c.assertExpected(t, got)
+				c.assertExpected(tt, got)
 			}
 		})
 	}
@@ -243,7 +242,6 @@ func TestGoogleBigtableTable(t *testing.T) {
 
 	for _, c := range cases {
 		t.Run(c.test, func(tt *testing.T) {
-			scanOptions := ScannerOptions{}
 			providerLibrary := terraform.NewProviderLibrary()
 			remoteLibrary := common.NewRemoteLibrary()
 
@@ -270,7 +268,7 @@ func TestGoogleBigtableTable(t *testing.T) {
 			testFilter := &enumeration.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
 
-			s := NewScanner(remoteLibrary, alerter, scanOptions, testFilter)
+			s := NewScanner(remoteLibrary, alerter, testFilter)
 			got, err := s.Resources()
 			assert.Equal(tt, err, c.wantErr)
 			if err != nil {
@@ -279,7 +277,7 @@ func TestGoogleBigtableTable(t *testing.T) {
 			alerter.AssertExpectations(tt)
 			testFilter.AssertExpectations(tt)
 			if c.assertExpected != nil {
-				c.assertExpected(t, got)
+				c.assertExpected(tt, got)
 			}
 		})
 	}
