@@ -18,10 +18,10 @@ import (
 
 	testgoogle "github.com/snyk/driftctl/test/google"
 
+	assetpb "cloud.google.com/go/asset/apiv1/assetpb"
 	terraform2 "github.com/snyk/driftctl/test/terraform"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
-	assetpb "google.golang.org/genproto/googleapis/cloud/asset/v1"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 )
@@ -103,7 +103,6 @@ func TestGoogleCloudRunService(t *testing.T) {
 
 	for _, c := range cases {
 		t.Run(c.test, func(tt *testing.T) {
-			scanOptions := ScannerOptions{}
 			providerLibrary := terraform.NewProviderLibrary()
 			remoteLibrary := common.NewRemoteLibrary()
 
@@ -130,7 +129,7 @@ func TestGoogleCloudRunService(t *testing.T) {
 			testFilter := &enumeration.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
 
-			s := NewScanner(remoteLibrary, alerter, scanOptions, testFilter)
+			s := NewScanner(remoteLibrary, alerter, testFilter)
 			got, err := s.Resources()
 			assert.Equal(tt, c.wantErr, err)
 			if err != nil {
@@ -140,7 +139,7 @@ func TestGoogleCloudRunService(t *testing.T) {
 			alerter.AssertExpectations(tt)
 			testFilter.AssertExpectations(tt)
 			if c.assertExpected != nil {
-				c.assertExpected(t, got)
+				c.assertExpected(tt, got)
 			}
 		})
 	}
