@@ -42,14 +42,12 @@ func TestScanCmd_Valid(t *testing.T) {
 		{args: []string{"scan", "--tfc-token", "token"}},
 		{args: []string{"scan", "--filter", "Type=='aws_s3_bucket'"}},
 		{args: []string{"scan", "--strict"}},
-		{args: []string{"scan", "--deep"}},
 		{args: []string{"scan", "--tf-provider-version", "1.2.3"}},
 		{args: []string{"scan", "--tf-provider-version", "3.30.2"}},
 		{args: []string{"scan", "--driftignore", "./path/to/driftignore.s3"}},
 		{args: []string{"scan", "--driftignore", ".driftignore"}},
 		{args: []string{"scan", "-o", "html://result.html", "-o", "json://result.json"}},
 		{args: []string{"scan", "--tf-lockfile", "../.terraform.lock.hcl"}},
-		{args: []string{"scan", "--only-managed"}},
 		{args: []string{"scan", "--only-unmanaged"}},
 	}
 
