@@ -38,9 +38,6 @@ type ScanOptions struct {
 	ConfigDir        string
 	DriftignorePath  string
 	Driftignores     []string
-	Deep             bool
-	OnlyManaged      bool
-	OnlyUnmanaged    bool
 }
 
 type DriftCTL struct {
