@@ -2,7 +2,7 @@ package backend
 
 import (
 	"fmt"
-	"io/ioutil"
+	"io"
 	"strings"
 	"testing"
 )
@@ -41,7 +41,7 @@ func TestTFCloudConfigReader_GetToken(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			readerCloser := ioutil.NopCloser(strings.NewReader(tt.src))
+			readerCloser := io.NopCloser(strings.NewReader(tt.src))
 			defer readerCloser.Close()
 			r := NewTFCloudConfigReader(readerCloser)
 			got, err := r.GetToken("app.terraform.io")
