@@ -2,6 +2,7 @@ package enumerator
 
 import (
 	"fmt"
+	"path"
 	"strings"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -46,10 +47,10 @@ func (s *S3Enumerator) Enumerate() ([]string, error) {
 	bucket := bucketPath[0]
 	// prefix should contains everything that does not have a glob pattern
 	// Pattern should be the glob matcher string
-	prefix, pattern := GlobS3(strings.Join(bucketPath[1:], "/"))
+	prefix, pattern := extractPrefixAndPattern(strings.Join(bucketPath[1:], "/"))
 
-	fullPattern := strings.Join([]string{prefix, pattern}, "/")
-	fullPattern = strings.Trim(fullPattern, "/")
+	// We combine the prefix and pattern to match file names against.
+	fullPattern := path.Join(prefix, pattern)
 
 	files := make([]string, 0)
 	input := &s3.ListObjectsV2Input{
