@@ -1,20 +1,20 @@
 package middlewares
 
 import (
-	"github.com/snyk/driftctl/enumeration/terraform"
 	"strings"
 	"testing"
 
 	"github.com/aws/aws-sdk-go/aws/awsutil"
 	"github.com/r3labs/diff/v2"
 	"github.com/snyk/driftctl/enumeration/resource"
-	"github.com/snyk/driftctl/enumeration/resource/aws"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/resource/aws"
 )
 
 func TestAwsEbsEncryptionByDefaultReconciler_Execute(t *testing.T) {
 	tests := []struct {
 		name                    string
-		mocks                   func(*terraform.MockResourceFactory)
+		mocks                   func(*dctlresource.MockResourceFactory)
 		remoteResources         []*resource.Resource
 		resourcesFromState      []*resource.Resource
 		expectedRemoteResources []*resource.Resource
@@ -22,7 +22,7 @@ func TestAwsEbsEncryptionByDefaultReconciler_Execute(t *testing.T) {
 	}{
 		{
 			name: "test encryption by default is managed",
-			mocks: func(factory *terraform.MockResourceFactory) {
+			mocks: func(factory *dctlresource.MockResourceFactory) {
 				factory.On("CreateAbstractResource",
 					aws.AwsEbsEncryptionByDefaultResourceType,
 					"terraform-20220328091515068500000001",
@@ -100,7 +100,7 @@ func TestAwsEbsEncryptionByDefaultReconciler_Execute(t *testing.T) {
 		},
 		{
 			name:  "test encryption by default is enabled and unmanaged",
-			mocks: func(factory *terraform.MockResourceFactory) {},
+			mocks: func(factory *dctlresource.MockResourceFactory) {},
 			remoteResources: []*resource.Resource{
 				{
 					Id:    "bucket-1",
@@ -146,7 +146,7 @@ func TestAwsEbsEncryptionByDefaultReconciler_Execute(t *testing.T) {
 		},
 		{
 			name:  "test encryption by default is disabled and unmanaged",
-			mocks: func(factory *terraform.MockResourceFactory) {},
+			mocks: func(factory *dctlresource.MockResourceFactory) {},
 			remoteResources: []*resource.Resource{
 				{
 					Id:   "test-encryption",
@@ -185,7 +185,7 @@ func TestAwsEbsEncryptionByDefaultReconciler_Execute(t *testing.T) {
 		},
 		{
 			name:  "test encryption by default doesn't exist",
-			mocks: func(factory *terraform.MockResourceFactory) {},
+			mocks: func(factory *dctlresource.MockResourceFactory) {},
 			remoteResources: []*resource.Resource{
 				{
 					Id:    "bucket-1",
@@ -242,7 +242,7 @@ func TestAwsEbsEncryptionByDefaultReconciler_Execute(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			factory := &terraform.MockResourceFactory{}
+			factory := &dctlresource.MockResourceFactory{}
 			if tt.mocks != nil {
 				tt.mocks(factory)
 			}
