@@ -5,7 +5,7 @@ import (
 	"github.com/snyk/driftctl/enumeration/alerter"
 
 	"github.com/snyk/driftctl/enumeration/resource"
-	"github.com/snyk/driftctl/enumeration/resource/aws"
+	"github.com/snyk/driftctl/pkg/resource/aws"
 )
 
 // Explodes routes found in aws_default_route_table.route and aws_route_table.route to dedicated resources
