@@ -1,6 +1,6 @@
 package middlewares
 
-import "github.com/snyk/driftctl/pkg/resource"
+import "github.com/snyk/driftctl/enumeration/resource"
 
 type Middleware interface {
 	Execute(remoteResources, resourcesFromState *[]*resource.Resource) error
