@@ -1,10 +1,13 @@
 package aws
 
-import "github.com/snyk/driftctl/pkg/resource"
+import (
+	"github.com/snyk/driftctl/enumeration/resource"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
+)
 
 const AwsApiGatewayV2ModelResourceType = "aws_apigatewayv2_model"
 
-func initAwsApiGatewayV2ModelMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+func initAwsApiGatewayV2ModelMetaData(resourceSchemaRepository dctlresource.SchemaRepositoryInterface) {
 	resourceSchemaRepository.SetHumanReadableAttributesFunc(
 		AwsApiGatewayV2ModelResourceType,
 		func(res *resource.Resource) map[string]string {
