@@ -11,10 +11,7 @@ func TestAcc_Aws_AppAutoScalingTarget(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_appautoscaling_target"},
-		Args: []string{
-			"scan",
-			"--deep",
-		},
+		Args:             []string{"scan"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
@@ -26,7 +23,6 @@ func TestAcc_Aws_AppAutoScalingTarget(t *testing.T) {
 					}
 					result.AssertInfrastructureIsInSync()
 					result.AssertManagedCount(1)
-					result.AssertDriftCountTotal(0)
 				},
 			},
 		},
