@@ -12,7 +12,7 @@ func TestAcc_Aws_DbSubnetGroup(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_db_subnet_group"},
-		Args:             []string{"scan", "--filter", "Id!='default'", "--deep"},
+		Args:             []string{"scan", "--filter", "Id!='default'"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
