@@ -11,7 +11,7 @@ func TestAcc_Aws_IamRole(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_iam_role"},
-		Args:             []string{"scan", "--deep"},
+		Args:             []string{"scan"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
@@ -21,7 +21,6 @@ func TestAcc_Aws_IamRole(t *testing.T) {
 					if err != nil {
 						t.Fatal(err)
 					}
-					result.AssertDriftCountTotal(0)
 					result.AssertDeletedCount(0)
 					result.AssertManagedCount(1)
 				},
@@ -44,7 +43,6 @@ func TestAcc_Aws_IamRole_WithManaged(t *testing.T) {
 					if err != nil {
 						t.Fatal(err)
 					}
-					result.AssertDriftCountTotal(0)
 					result.AssertDeletedCount(0)
 					result.AssertManagedCount(2)
 				},
