@@ -11,7 +11,7 @@ func TestAcc_Aws_Route53Record_WithFQDNAsId(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_route53_record"},
-		Args:             []string{"scan", "--deep"},
+		Args:             []string{"scan"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
@@ -21,7 +21,6 @@ func TestAcc_Aws_Route53Record_WithFQDNAsId(t *testing.T) {
 					if err != nil {
 						t.Fatal(err)
 					}
-					result.AssertDriftCountTotal(0)
 					result.Equal(0, result.Summary().TotalDeleted)
 					result.Equal(9, result.Summary().TotalManaged)
 				},
@@ -34,7 +33,7 @@ func TestAcc_Aws_Route53Record_WithAlias(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_route53_record_with_alias"},
-		Args:             []string{"scan", "--deep"},
+		Args:             []string{"scan"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
@@ -44,7 +43,6 @@ func TestAcc_Aws_Route53Record_WithAlias(t *testing.T) {
 					if err != nil {
 						t.Fatal(err)
 					}
-					result.AssertDriftCountTotal(0)
 					result.Equal(2, result.Summary().TotalManaged)
 				},
 			},
