@@ -11,7 +11,7 @@ func TestAcc_Aws_SecurityGroupRule(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_security_group_rule"},
-		Args:             []string{"scan", "--deep"},
+		Args:             []string{"scan"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
@@ -24,7 +24,6 @@ func TestAcc_Aws_SecurityGroupRule(t *testing.T) {
 					result.AssertManagedCount(21)
 					result.AssertDeletedCount(2)
 					result.AssertUnmanagedCount(5)
-					result.AssertDriftCountTotal(0)
 				},
 			},
 		},
