@@ -10,26 +10,14 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAwsApiGatewayV2ModelMetaData(resourceSchemaRepository)
 	initAwsAppAutoscalingPolicyMetaData(resourceSchemaRepository)
 	initAwsDefaultRouteTableMetadata(resourceSchemaRepository)
-	initAwsDefaultVpcMetaData(resourceSchemaRepository)
-	initAwsEbsEncryptionByDefaultMetaData(resourceSchemaRepository)
-	initAwsEipAssociationMetaData(resourceSchemaRepository)
 	initAwsIAMRolePolicyMetaData(resourceSchemaRepository)
-	initAwsIamRolePolicyAttachmentMetaData(resourceSchemaRepository)
 	initAwsIAMUserPolicyMetaData(resourceSchemaRepository)
-	initAwsIamUserPolicyAttachmentMetaData(resourceSchemaRepository)
 	initAwsInternetGatewayMetaData(resourceSchemaRepository)
 	initAwsLaunchTemplateMetaData(resourceSchemaRepository)
 	initAwsLoadBalancerMetaData(resourceSchemaRepository)
-	initNatGatewayMetaData(resourceSchemaRepository)
-	initAwsNetworkACLMetaData(resourceSchemaRepository)
 	initAwsRoute53HealthCheckMetaData(resourceSchemaRepository)
 	initAwsRouteTableMetaData(resourceSchemaRepository)
 	initAwsRouteTableAssociationMetaData(resourceSchemaRepository)
-	initAwsS3BucketAnalyticsConfigurationMetaData(resourceSchemaRepository)
-	initAwsS3BucketInventoryMetadata(resourceSchemaRepository)
-	initAwsS3BucketMetricMetadata(resourceSchemaRepository)
-	initAwsS3BucketNotificationMetadata(resourceSchemaRepository)
-	initSqsQueueMetaData(resourceSchemaRepository)
 	initAwsVpcMetaData(resourceSchemaRepository)
 	initAwsCloudfrontDistributionMetaData(resourceSchemaRepository)
 	initAwsDbInstanceMetaData(resourceSchemaRepository)
@@ -69,5 +57,4 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAwsRDSClusterMetaData(resourceSchemaRepository)
 	initAwsCloudformationStackMetaData(resourceSchemaRepository)
 	initAwsAppAutoscalingTargetMetaData(resourceSchemaRepository)
-	initAwsCloudtrailMetaData(resourceSchemaRepository)
 }
