@@ -1,10 +1,13 @@
 package azurerm
 
-import "github.com/snyk/driftctl/pkg/resource"
+import (
+	"github.com/snyk/driftctl/enumeration/resource"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
+)
 
 const AzurePostgresqlServerResourceType = "azurerm_postgresql_server"
 
-func initAzurePostgresqlServerMetadata(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+func initAzurePostgresqlServerMetadata(resourceSchemaRepository dctlresource.SchemaRepositoryInterface) {
 	resourceSchemaRepository.SetHumanReadableAttributesFunc(AzurePostgresqlServerResourceType, func(res *resource.Resource) map[string]string {
 		val := res.Attrs
 		attrs := make(map[string]string)
