@@ -1,12 +1,13 @@
 package azurerm
 
 import (
-	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/enumeration/resource"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
 )
 
 const AzureRouteResourceType = "azurerm_route"
 
-func initAzureRouteMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+func initAzureRouteMetaData(resourceSchemaRepository dctlresource.SchemaRepositoryInterface) {
 	resourceSchemaRepository.SetHumanReadableAttributesFunc(AzureRouteResourceType, func(res *resource.Resource) map[string]string {
 		attrs := make(map[string]string)
 
