@@ -23,19 +23,19 @@ func TestAzureMetadata_Flags(t *testing.T) {
 		azurerm.AzureStorageContainerResourceType:      {},
 		azurerm.AzureSubnetResourceType:                {},
 		azurerm.AzureVirtualNetworkResourceType:        {},
-		azurerm.AzureNetworkSecurityGroupResourceType:  {resource.FlagDeepMode},
+		azurerm.AzureNetworkSecurityGroupResourceType:  {},
 		azurerm.AzureLoadBalancerResourceType:          {},
-		azurerm.AzurePrivateDNSZoneResourceType:        {resource.FlagDeepMode},
-		azurerm.AzurePrivateDNSARecordResourceType:     {resource.FlagDeepMode},
-		azurerm.AzurePrivateDNSAAAARecordResourceType:  {resource.FlagDeepMode},
-		azurerm.AzurePrivateDNSCNameRecordResourceType: {resource.FlagDeepMode},
-		azurerm.AzurePrivateDNSPTRRecordResourceType:   {resource.FlagDeepMode},
-		azurerm.AzurePrivateDNSMXRecordResourceType:    {resource.FlagDeepMode},
-		azurerm.AzurePrivateDNSSRVRecordResourceType:   {resource.FlagDeepMode},
-		azurerm.AzurePrivateDNSTXTRecordResourceType:   {resource.FlagDeepMode},
+		azurerm.AzurePrivateDNSZoneResourceType:        {},
+		azurerm.AzurePrivateDNSARecordResourceType:     {},
+		azurerm.AzurePrivateDNSAAAARecordResourceType:  {},
+		azurerm.AzurePrivateDNSCNameRecordResourceType: {},
+		azurerm.AzurePrivateDNSPTRRecordResourceType:   {},
+		azurerm.AzurePrivateDNSMXRecordResourceType:    {},
+		azurerm.AzurePrivateDNSSRVRecordResourceType:   {},
+		azurerm.AzurePrivateDNSTXTRecordResourceType:   {},
 		azurerm.AzureImageResourceType:                 {},
-		azurerm.AzureSSHPublicKeyResourceType:          {resource.FlagDeepMode},
-		azurerm.AzureLoadBalancerRuleResourceType:      {resource.FlagDeepMode},
+		azurerm.AzureSSHPublicKeyResourceType:          {},
+		azurerm.AzureLoadBalancerRuleResourceType:      {},
 	}
 
 	schemaRepository := testresource.InitFakeSchemaRepository("azurerm", "2.71.0")
