@@ -1,6 +1,8 @@
 package github
 
-import "github.com/snyk/driftctl/enumeration/resource"
+import (
+	"github.com/snyk/driftctl/pkg/resource"
+)
 
 func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInterface) {
 	initGithubBranchProtectionMetaData(resourceSchemaRepository)
