@@ -1,10 +1,13 @@
 package google
 
-import "github.com/snyk/driftctl/pkg/resource"
+import (
+	"github.com/snyk/driftctl/enumeration/resource"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
+)
 
 const GoogleComputeDiskResourceType = "google_compute_disk"
 
-func initGoogleComputeDiskMetadata(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+func initGoogleComputeDiskMetadata(resourceSchemaRepository dctlresource.SchemaRepositoryInterface) {
 	resourceSchemaRepository.SetHumanReadableAttributesFunc(GoogleComputeDiskResourceType, func(res *resource.Resource) map[string]string {
 		return map[string]string{
 			"Name": *res.Attributes().GetString("name"),
